Opts

Struct Opts 

pub struct Opts {
    pub command: Option<ClonableCommand>,
    pub file: Option<NormalPath>,
    pub error_file: Option<Utf8PathBuf>,
    pub enable_eval: bool,
    pub extra_module_search_paths: Vec<NormalPath>,
    pub clear: bool,
    pub experimental_features: Vec<ExperimentalFeature>,
    pub tui: bool,
    pub completions: Option<Shell>,
    pub hooks: HookOpts,
    pub watch: WatchOpts,
    pub logging: LoggingOpts,
    /* private fields */
}
Ghciwatch loads a GHCi session for a Haskell project and reloads it when source files change.

Fields

command: Option<ClonableCommand>

A shell command which starts a GHCi REPL, e.g. ghci or cabal v2-repl or similar.

This is used to launch the underlying GHCi session that ghciwatch controls.

May contain quoted arguments which will be parsed in a sh-like manner.

file: Option<NormalPath>

A Haskell source file to load into a GHCi REPL.

Shortcut for --command 'ghci PATH'. Conflicts with --command.

error_file: Option<Utf8PathBuf>

A file to write compilation errors to.

The output format is compatible with ghcid’s --outputfile option.

enable_eval: bool

Evaluate Haskell code in comments.

This parses line commands starting with -- $> or multiline commands delimited by {- $> and <$ -} and evaluates them after reloads.

extra_module_search_paths: Vec<NormalPath>

An extra directory for converting module paths to module names and vice versa, in addition to the module import search paths from GHCi’s :show paths output.

In some setups (like multi-package projects), GHCi’s search paths don’t include the source directories of all loaded packages, so converting between source paths and module names can fail. Use this option to supplement the search paths with extra directories, like my-package/src.

Can be given multiple times.

clear: bool

Clear the screen before reloads and restarts.

experimental_features: Vec<ExperimentalFeature>

Enable experimental features. These features are unsupported and may change or be removed without notice.

Can be given multiple times.

tui: bool

Deprecated: use --experimental-features tui instead.

completions: Option<Shell>

Generate shell completions for the given shell.

hooks: HookOpts

Lifecycle hooks and commands to run at various points.

watch: WatchOpts

Options to modify file watching.

logging: LoggingOpts

Options to modify logging and error-handling behavior.

Implementations

Source

impl Opts

pub fn interrupt_reloads(&self) -> bool

Should reloads be interrupted with Ctrl-C when files change?

pub fn has_experimental_feature(&self, feature: ExperimentalFeature) -> bool

Check whether a given experimental feature has been enabled.

pub fn init(&mut self) -> Result<()>

Perform late initialization of the command-line arguments. If init isn’t called before the arguments are used, the behavior is undefined.